pub(crate) fn kind_meaning(kind: PropertyKind) -> &'static strExpand description
The canonical meaning template for a property kind (the first tag that maps
to kind). Argument-dependent kinds override this at render time.
pub(crate) fn kind_meaning(kind: PropertyKind) -> &'static strThe canonical meaning template for a property kind (the first tag that maps
to kind). Argument-dependent kinds override this at render time.